SISCone: Download

# SISCone Documentation

### Version 3.0.6

## Downloading SISCone

You can download here the of SISCone source code. It is developped under the terms of the GNU General Public License (GPL). A version of the license should be included in the code.

The algorithm used by SISCone has been subject of a publication in JHEP 05 (2007) 086 [arXiv:0704.0292 (hep-ph)]. Please refer to that work each time it is appropriate.

Download SISCone 3.0.6 (latest stable - June 20 2023 - Release notes)

You can alternatively download SISCone from its git repository. This can be browsed via the webpage or cloned using either `https://gitlab.com/fastjet/siscone.git` (https) or `git@gitlab.com:fastjet/siscone.git` (ssh).

Home
Contacts: Gregory Soyez Gavin Salam